#
# spec file for package mopac7
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         libname  libmopac7-1
Name:           mopac7
Version:        1.15
Release:        8.6
Summary:        Semi-empirical quantum mechanics suite
License:        SUSE-Public-Domain
Group:          Productivity/Scientific/Chemistry
URL:            https://sourceforge.net/projects/mopac7/
Source0:        http://www.bioinformatics.org/ghemical/download/current/%{name}-%{version}.tar.gz
Source99:       baselibs.conf
Patch1:         mopac7-1.14-random_data.patch
Patch2:         mopac7-1.14-libdir.patch
# PATCH-FEATURE-OPENSUSE mopac7-fortify.patch -- fix for building with gcc7
Patch3:         mopac7-fortify.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-fortran
BuildRequires:  libtool
BuildRequires:  pkgconfig
%{?suse_build_hwcaps_libs}

%description
MOPAC7 is a semi-empirical quantum-mechanics code written by James J. P.
Stewart and co-workers. The purpose of this project is to maintain MOPAC7 as
a stand-alone program as well as a library that provides the functionality
of MOPAC7 to other programs.

%package -n	%{libname}
Summary:        Dynamic libraries from %{name}
Group:          System/Libraries

%description -n	%{libname}
MOPAC7 is a semi-empirical quantum-mechanics code written by James J. P.
Stewart and co-workers. The purpose of this project is to maintain MOPAC7 as
a stand-alone program as well as a library that provides the functionality
of MOPAC7 to other programs.

This package contains dynamic libraries.

%package    -n %{libname}-devel
Summary:        Header files and static libraries from %{name}
Group:          Development/Languages/C and C++
Requires:       %{libname} = %{version}

%description -n %{libname}-devel
MOPAC7 is a semi-empirical quantum-mechanics code written by James J. P.
Stewart and co-workers. The purpose of this project is to maintain MOPAC7 as
a stand-alone program as well as a library that provides the functionality
of MOPAC7 to other programs.

This package contains development files.

%prep
%autosetup -p1

%build
autoreconf -fiv
# http://www.bioinformatics.org/pipermail/ghemical-devel/2008-August/000763.html
export FFLAGS="%{optflags} -std=legacy -fno-automatic"
%ifarch aarch64 %{arm}
export FFLAGS="%{optflags} -fPIC"
%endif
%configure \
  --disable-static
%make_build

%install
%make_install
mkdir -p %{buildroot}%{_bindir}
libtool --mode=install install -m 755 fortran/%{name} %{buildroot}%{_bindir}/%{name}
sed -e "s|\./src|%{_bindir}|g" run_mopac7 > %{buildroot}%{_bindir}/run_mopac7
rm tests/Makefile*
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%doc AUTHORS ChangeLog NEWS README tests
%attr(755,root,root) %{_bindir}/run_mopac7
%{_bindir}/%{name}

%files -n %{libname}
%license COPYING
%{_libdir}/libmopac7.so.*

%files -n %{libname}-devel
%{_includedir}/%{name}
%{_libdir}/libmopac7.so
%{_libdir}/pkgconfig/libmopac7.pc

%changelog
* Wed Mar  8 2023 Martin Pluskal <mpluskal@suse.com>
- Build AVX2 enabled hwcaps library for x86_64-v3
* Tue Jun  9 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build on aarch64 %%arm by adding '-fPIC' flag
* Fri Sep 20 2019 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file by using latest macros
* Mon Mar 18 2019 lars@linux-schulserver.de - 1.15
- weaken the dependency of the devel package (no exact release needed)
- use new %%%%license macro
* Tue Jun  6 2017 mpluskal@suse.com
- Add mopac7-fortify.patch to fix building on latest Factory
* Sun Jan 29 2017 mpluskal@suse.com
- Update compiler flags
* Fri Jan 22 2016 mpluskal@suse.com
- Cleanup spec file
- Do not ship .la file
* Thu Feb 26 2015 mpluskal@suse.com
- Use source url
* Sat Feb 21 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Update dependencies
  * remove f2c
  * remove explicit dependencies for devel package
  * add pkg-config and full autotools
* Wed Jan 16 2013 lars@linux-schulserver.de
- explicit require libtool
* Tue Oct  9 2012 lars@linux-schulserver.de
- change provides
* Fri Jan 21 2011 embar@users.berlios.de
- update to 1.15
* Sun Mar 15 2009 lars@linux-schulserver.de
- update to 1.14
- adapted patches for new version
* Tue Dec 30 2008 lars@linux-schulserver.de
- use libtoolize and aclocal to get it build for 11.1 again
* Thu Sep 25 2008 lars@linux-schulserver.de
- moved to Education base repository
* Mon May 19 2008 lars@linux-schulserver.de
- fix rpm group
* Mon May 19 2008 lars@linux-schulserver.de
- upadte to 1.13:
  Including changes made by Tommi Hassinen, University of Kuopio,
  Finland, April 2001.
* Mon Mar 24 2008 lars@linux-schulserver.de
- initial version 1.10 for openSUSE
